@@ -18,7 +18,7 @@
 #include "ruby.h"
 
 
-#define TMAIL_VERSION "0.9.0"
+#define TMAIL_VERSION "0.9.1"
 
 static VALUE MailScanner;
 static VALUE ScanError;
@@ -191,7 +191,7 @@ scan_word(sc, special)
 }
 
 #define ATOM_SPECIAL  "()<>[]@,;:\"\\."
-#define TOKEN_SPECIAL "()<>[]@,;:\"\\?="
+#define TOKEN_SPECIAL "()<>[]@,;:\"\\/?="
 
 static VALUE
 scan_atom(sc)
